==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDAREA.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELD" maxOccurs="500" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STATUSCODE" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="customfieldlimitexceeded" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customfield",
    "statuscode"
})
@XmlRootElement(name = "USERDEFINEDAREA")
public class USERDEFINEDAREA {

    @XmlElement(name = "CUSTOMFIELD")
    protected List<CUSTOMFIELD> customfield;
    @XmlElement(name = "STATUSCODE")
    protected String statuscode;
    @XmlAttribute(name = "customfieldlimitexceeded")
    protected String customfieldlimitexceeded;

    /**
     * Gets the value of the customfield property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the customfield property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getCUSTOMFIELD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CUSTOMFIELD }
     * 
     * 
     * @return
     *     The value of the customfield property.
     */
    public List<CUSTOMFIELD> getCUSTOMFIELD() {
        if (customfield == null) {
            customfield = new ArrayList<>();
        }
        return this.customfield;
    }

    /**
     * Gets the value of the statuscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATUSCODE() {
        return statuscode;
    }

    /**
     * Sets the value of the statuscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATUSCODE(String value) {
        this.statuscode = value;
    }

    /**
     * Gets the value of the customfieldlimitexceeded property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCustomfieldlimitexceeded() {
        return customfieldlimitexceeded;
    }

    /**
     * Sets the value of the customfieldlimitexceeded property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCustomfieldlimitexceeded(String value) {
        this.customfieldlimitexceeded = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDAREA.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELD" maxOccurs="500" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUSCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="customfieldlimitexceeded" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "customfield",
    "statuscode"
})
@XmlRootElement(name = "USERDEFINEDAREA")
public class USERDEFINEDAREA {

    @XmlElement(name = "CUSTOMFIELD")
    protected List<CUSTOMFIELD> customfield;
    @XmlElement(name = "STATUSCODE")
    protected String statuscode;
    @XmlAttribute(name = "customfieldlimitexceeded")
    protected String customfieldlimitexceeded;

    /**
     * Gets the value of the customfield property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the customfield property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getCUSTOMFIELD().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CUSTOMFIELD }
     * 
     * 
     */
    public List<CUSTOMFIELD> getCUSTOMFIELD() {
        if (customfield == null) {
            customfield = new ArrayList<CUSTOMFIELD>();
        }
        return this.customfield;
    }

    /**
     * Gets the value of the statuscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSTATUSCODE() {
        return statuscode;
    }

    /**
     * Sets the value of the statuscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSTATUSCODE(String value) {
        this.statuscode = value;
    }

    /**
     * Gets the value of the customfieldlimitexceeded property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCustomfieldlimitexceeded() {
        return customfieldlimitexceeded;
    }

    /**
     * Sets the value of the customfieldlimitexceeded property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCustomfieldlimitexceeded(String value) {
        this.customfieldlimitexceeded = value;
    }

}
